==> citron-0.4.1.crate: citron-0.4.1/src/debug.rs <==
use colored::*;
use libmacchina::extra::list_dir_entries;
use std::path::PathBuf;

fn basename(path: &str) -> &str {
    let mut pieces = path.rsplit('/');
    match pieces.next() {
        Some(p) => p,
        None => path,
    }
}

fn library_locations() -> Vec<PathBuf> {
    let mut locations = vec![];
    if cfg!(target_os = "linux") {
        locations.push("/lib");
    } else if cfg!(target_os = "netbsd") {
        locations.push("/usr/pkg/lib");
    } else if cfg!(target_family = "unix") {
        locations.push("/usr/local/lib");
    }

    locations.iter().map(|&x| PathBuf::from(x)).collect()
}

pub fn get_debug() {
    let base_locations = library_locations();

    let found = base_locations.iter().find(|&x| {
        let libraries = list_dir_entries(x);
        libraries.iter().any(|l| {
            let file = basename(l.to_str().unwrap_or_default());
            file.starts_with("libdbus-") && file.ends_with("so")
        })
    });

    if found.is_some() {
        println!("- Searching for libdbus: {}", "OK".green());
    } else {
        println!("- Searching for libdbus: {}", "FAILED".red());
    }

    let capabilities = notify_rust::get_capabilities();
    if let Ok(capab) = capabilities {
        let mut list = vec![];
        println!("- Identifying your daemon's capabilities: {}", "OK".green());
        for c in capab {
            list.push(c);
        }
        println!("  -> {}", list.join(", "));
    } else {
        println!(
            "- Identifying your daemon's capabilities: {}",
            "FAILED".red()
        );
        println!("  -> Do you have a notification daemon running/installed?");
        println!("  -> Are you in a graphical session?");
    }

    println!(
        "\nStill encountering issues?\nReport a bug at https://github.com/grtcdr/citron/issues"
    )
}

==> citron-0.6.0.crate: citron-0.6.0/src/debug.rs <==
use crate::helpers;
use libmacchina::extra::list_dir_entries;
use owo_colors::OwoColorize;
use std::path::PathBuf;

fn library_locations() -> Vec<PathBuf> {
    let mut locations = vec![];
    if cfg!(target_os = "linux") {
        locations.push("/lib");
    } else if cfg!(target_os = "netbsd") {
        locations.push("/usr/pkg/lib");
    } else if cfg!(target_family = "unix") {
        locations.push("/usr/local/lib");
    }

    locations.iter().map(|&x| PathBuf::from(x)).collect()
}

pub fn get_debug() {
    check_libdbus();
    check_daemon_capabilities();
    println!(
        "\nStill encountering issues?\nReport a 🐛 bug at {}",
        "https://github.com/grtcdr/citron/issues".blue()
    );
}

fn check_libdbus() {
    let base_locations = library_locations();

    let found = base_locations.iter().find(|&x| {
        let libraries = list_dir_entries(x);
        libraries.iter().any(|l| {
            let file = helpers::basename(l.to_str().unwrap_or_default());
            file.starts_with("libdbus-") && file.ends_with("so")
        })
    });

    if found.is_some() {
        println!("- Searching for libdbus: {}", "OK".green());
    } else {
        println!("- Searching for libdbus: {}", "FAILED".red());
    }
}

fn check_daemon_capabilities() {
    let capabilities = notify_rust::get_capabilities();
    if let Ok(capab) = capabilities {
        let mut list = vec![];
        println!("- Identifying your daemon's capabilities: {}", "OK".green());
        for c in capab {
            list.push(c);
        }
        println!("  * {}", list.join(", "));
    } else {
        println!(
            "- Identifying your daemon's capabilities: {}",
            "FAILED".red()
        );
        println!("  * Do you have a notification daemon running/installed?",);
        println!("  * Are you in a graphical session?");
    }
}
